#
# spec file for package gns3-server
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%if %{undefined suse_version}

# get python versions
%global py3_ver %(if [ -f "%{__python3}" ]; then %{__python3} -c "import sys; sys.stdout.write(sys.version[:3])"; else echo 0; fi;)

%endif

Name:           gns3-server
Summary:        GNS3 is a graphical network simulator
License:        GPL-3.0+
Group:          Productivity/Networking/Other
Version:        1.3.1
Release:        5.2
Url:            http://www.gns3.net/
Source0:        %{name}-%{version}.tar.gz
BuildRequires:  python3-devel >= 3.3
BuildRequires:  python3-netifaces
BuildRequires:  python3-pip
BuildRequires:  python3-setuptools
Requires:       cpulimit
Requires:       dynamips >= 0.2.11
Requires:       iouyap
Requires:       python3-Jinja2 >= 2.7.3
Requires:       python3-aiohttp
Requires:       python3-jsonschema >= 2.3.0
Requires:       python3-netifaces
Requires:       python3-raven
Requires:       qemu
Requires:       vpcs >= 0.5b1
Requires:       wireshark
%if 0%{?suse_version}
Recommends:     virtualbox
%endif
BuildArch:      noarch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
The GNS3 server manages emulators such as Dynamips, VirtualBox or Qemu/KVM.
Clients like the GNS3 GUI controls the server using a JSON-RPC API over Websockets.

You will need the new GNS3 GUI (gns3-gui repository) to control the server.

%prep
%setup -q

%build
python3 setup.py build

%install
python3 setup.py install --root=%{buildroot} --prefix=%{_prefix}
chmod +x %{buildroot}/%{python3_sitelib}/gns3server/main.py
chmod +x %{buildroot}/%{python3_sitelib}/gns3server/modules/iou/ioucon.py
rm -rf %{buildroot}/%{python3_sitelib}/tests

%files
%defattr(-, root, root, 0755)
%doc AUTHORS LICENSE README.rst
%{_bindir}/gns3server
%{_bindir}/gns3dms
%{python3_sitelib}/gns3server
%{python3_sitelib}/gns3_server-%{version}-py%{py3_ver}.egg-info

%changelog
* Sun Apr 12 2015 andrea@opensuse.org
- New upstream version 1.3.1
  * Initial config file content can be empty (fix export issues)
  * Fix crash if IOU initial config is emtpy
  * Return more informations about bad requests for crash reports
  * Allow less strict dependencies for easier install
  * Missing project name in documentation
  * Some spring cleaning
  * Fix missing IOU documentation
  * Add missing project name in curl documentation
  * Look in old IOU images location in order to smooth transition
  * Do not overwrite initial-config IOU if client send an empty
  * Fix documentation about /ports/udp
  * Fix issues with macos X dynamips not freeing UDP port
  * Fix encoding error when saving dynamips configuration
  * The upload web page return a 200 in case of error (IE compatibility)
  * Do not crash if dynamips config contain non ascii chars
  * Test path with chinese charcaters in Qemu
  * Do not crash if no console port is available for VBox
  * Raise a DynamipsError if we can't access to VM status
  * Check name of the VBoxManage executable
  * Exclude docs and tests package from distribution
  * Catch error when qemu additional options are invalid
  * Fix ClientDisconnectedError
  * Fix crash when NIO doesn't exist
  * Turn off crash report if raven not available
  * Fix crash when IOU script file is incorrect
* Sun Apr 12 2015 andrea@opensuse.org
- New upstream version 1.3.0
  * Fix issue when asyncio read is cancelled and data is still sent by Dynamips hypervisor.
  * Fix unicode decode error when saving IOS router configs.
  * Fix error when missing adapter in Dynamips IOS router.
  * Fix crash if we call stop on dynamips on non started process.
  * Fix use_default_iou_values param was not set.
  * Fix issue when IOURC environment variable is set to None.
  * Fix issue when exporting IOS router configs.
  * Fix check if VPCS process is running.
  * Fix bug when remove_nio() is not a coroutine for ATM and FR switches.
  * Fix how to test if iou and iouyap are running.
  * Allocate a random port for Qemu monitor. Fixes issue with pre 1.3 projects.
  * Fix default chassis bug.
- removed python3-zmq from requires and buildrequired
* Wed Apr  1 2015 andrea@opensuse.org
- New upstream version 1.2.4
  * Fix issue when asyncio read is cancelled and data is still sent by Dynamips hypervisor.
  * Fix unicode decode error when saving IOS router configs.
  * Fix error when missing adapter in Dynamips IOS router.
  * Fix crash if we call stop on dynamips on non started process.
  * Fix use_default_iou_values param was not set.
  * Fix issue when IOURC environment variable is set to None.
  * Fix issue when exporting IOS router configs.
  * Fix check if VPCS process is running.
  * Fix bug when remove_nio() is not a coroutine for ATM and FR switches.
  * Fix how to test if iou and iouyap are running.
  * Allocate a random port for Qemu monitor. Fixes issue with pre 1.3 projects.
  * Fix default chassis bug.
  * Update sentry key
  * For more detailed changelog visit https://github.com/GNS3/gns3-server/releases
* Sat Jan 17 2015 andrea@opensuse.org
- New upstream version 1.2.3
  * Fixed temporary files path setting in general preferences which was not used.
  * Fixed missing devices from the node view when they use a remote server.
  * Fixed broken ASA kernel/initrd file browsers.
  * Fixed bug with WICs interfaces no showing up in the port list.
  * Fixed broken -netdev + legacy virtio in Qemu support.
- New upstream version 1.2.2
  - Small improvements / new features
  * Auxiliary console support for IOS routers.
  * Suspend / resume support for Qemu.
  * Dynamically configure network connections of running Qemu VMs (only with recent Qemu versions).
  * VPCS multi-host support (useful for old .net labs).
  * EtherSwitch routers can be added and configured like other IOS routers.
  * Change hostname option in the contextual device menu.
  * Import & export config options in contextual device menu.
  * Auto screenshot when saving a project.
  * Auto start project support (you have to manually edit your .gns3 project file).
  * Possibility to run VirtualBox as another user (Linux/OSX only).
  * Changes to the IOU L2 initial-config (16 Ethernet interfaces, no shutdown by default and 0 serial interfaces).
  * Upgraded SuperPutty to version 1.4.0.5 in the all-in-one installer.
  * Support for IOURC file on the server side.
  * Bumped the maximum network adapters to 32 for Qemu (depending on Qemu version you cannot go above 8 or
    even 28, Qemu will just not start).
  * Possibility to apply or not the same text to all selected items when editing notes.
  * Added snapshot named 'reset' to linked cloned VirtualBox VMs.
  * Base configs are now stored in the GNS3 config directory.
  * Short port names in the topology summary.
  * Added the VirtualBox VM name in VirtualBox device tooltips.
  * More network interface options to the Qemu VM configuration interface as well as descriptions for all NICs.
  * Set 5 seconds timeout for local server connections.
  * Check if any device runs and warn the user before closing a project.
  * Restore the debug level status when starting.
  * Automatically select the symbol and category corresponding the edited item in the symbol selection dialog.
  * Scale SVG images to icon sizes.
  * Console switching from local/remote to remote/local while a VirtualBox VM is running.
  * More checks on minimum RAM for IOS routers and updates default values to match the latest IOS image requirements.
  * Default Jungle dock location is now bottom right corner.
  - Bug fixes
  * Fixed the default jungle news loading on Windows.
  * Fixed SuperPutty integration (not the default, still have to select it in the preferences).
  * Avoid uninitialized nodes to be saved in the project file.
  * Fixed bug when importing Host node with UDP NIOs.
  * Prevent GNS3 to crash on Windows when importing GNS3 config file.
  * Fixed resource access on Mac OS X.
  * Fixed transparency or border style restoration for ellipses and rectangles.
  * Support spaces in the controller name of VirtualBox clones.
  * Ignore Unicode errors when executing vboxmanage.
  * Get Windows interface list from the registry if the COM service fails.
* Fri Dec 26 2014 andrea@opensuse.org
- added cpulimit to requirements
* Sat Dec  6 2014 andrea@opensuse.org
- clean up in the dependencies list.
  * qemu and wireshark are now required not just recommended
  * vde2 and xdotool have been removed, they aren't used at all
* Fri Dec  5 2014 andrea@opensuse.org
- New upstream version 1.2.1
  * Early support for IOSv and IOSv-L2 (with Qemu for now, which is slow on Windows/Mac OS X).
  * Support for CPU throttling and process priority for Qemu.
  * Support for full screen mode (View -> Fullscreen).
  * Bundled Qemu 0.13.0 in the Windows all-in-one. Default for all local Qemu VMs.
  * Bundled Qemu 0.14.1 in the Mac OS X App. Default for all local Qemu VMs.
  * Changed ASA defaults to use Qemu 0.13.0 (on Windows), have 4 interfaces and CPU throttling to 65%%.
  * Fixed SecureCRT command line when space in the device name.
  * Fixed C7200 IO cards insert/remove issues and makes C7200-IO-FE the default.
  * Fixed port sorting issues.
  * Added default path for VBoxManage on Mac OS X
  * Upgraded gns3-converter to version 1.1.1 for Windows all-in-one and Mac OS X DMG.
  * New idle-PC field validation.
  * Possibility to load the project from command line (or double-click on a project on Windows).
  * Fixed Unicode error when using VirtualBox VM with a name containing non-english characters.
  * Updated the IOU VM with iouyap version 0.95 (packet capture).
* Tue Nov 25 2014 andrea@opensuse.org
- Fixed license tag
* Sat Nov 22 2014 andrea@opensuse.org
- dropped vboxwrapper in favour of VBoxManage provided by virtualbox
* Thu Nov 20 2014 andrea@opensuse.org
- new upstream version 1.2
  * New VirtualBox support.
  * New GUI styles: charcoal (default) & classic. Changing GUI Preferences
  * Integration of GNS3 converter (allows old .net topologies to be opened).
  * VirtualBox linked clones support (experimental, still some problems with temporary projects).
  * Allow Qemu VM to have no interface.
  * Option to allow console connections to any local IP address when using the local server.
  * Automatically extract IOS configs when a project is closed.
  * Fix "new project" bug when using the GNS3 IOU VM.
  * qemu-system-i386 is the new default on 32-bit platforms.
  * Option to deactivate the new project dialog at startup.
  * Add "open a project" and "recent projects" buttons to the new project dialog.
  * New host node (cloud with all available Ethernet & TAP interfaces added).
  * Fix platform detection issue with some Cisco IOS image file name.
  * Add delay (default 500 ms) when Console to all nodes.
  * Check for duplicate node names in Preferences.
  * Fix bug when editing a Qemu VM configured to run on a remote server.
  * News dock widget is smaller.
  * Add detection of qemu and qemu.exe binaries.
  * New Telnet server for VirtualBox.
* Sat Nov 15 2014 andrea@opensuse.org
- added new dependency python3-apache-libcloud
* Thu Oct 23 2014 andrea@opensuse.org
- new upstream version 1.1
- bug fixes
  * Warning message when using a remote server with IOU
  * Serial console for VirtualBox
  * Fixes EtherSwitch router
  * New Idle-PC dialog
  * Fixes #123 (Qemu binaries list not showing up)
  * Fixes #119
  * Fixes #126 (broken remote server feature)
  * Fixes #120 (broken cloud)
* Tue Oct 21 2014 andrea@opensuse.org
- New upstream version 1.0
- New features
  * Snapshots support (currently only for local projects).
  * Possibility to configure a category for nodes (routers,
    switches, end devices or security devices).
  * Added support for xfce4-terminal, for Xubuntu.
  * Remote servers and load-balancing (some bugs, still
    things to improve).
  * Check for update feature.
  * GNS3 Jungle dock widget.
  * Getting started dialog.
  * Added path lookup directory for Qemu on OSX.
  * Bug fix when loading a project containing a remote server.
- Know issues and notes
  * VirtualBox support doesn’t work on Mac OS X.
  * VirtualBox support on other platforms hasn’t been fully tested
    and bugs may still be present.
  * Again, regarding VirtualBox integration, we have plans to rewrite
    the back-end to add more features and remove the dependency
    on vboxwrapper.
* Mon Oct 20 2014 andrea@opensuse.org
- New upstream version 1.0 Beta 4
- New features:
  * Preferences has been completely re-vamped for the
    various emulators: Dynamips, IOU, VirtualBox and Qemu.
-Know issues and notes
  * VirtualBox/QEMU on Mac OS X hasn’t been tested at all.
  * VirtualBox support on other platforms hasn’t been fully tested
  and bugs may still be present.
  * Regarding VirtualBox integration, we have plans to rewrite the
  back-end to add more features and remove the dependency on vboxwrapper.
* Thu Sep 25 2014 andrea@opensuse.org
- New upstream version 1.0 Beta 3
- New features
  * QEMU integration with ASA and IDS pre-configuration options.
  * Solarwinds Response Time Viewer integration (Windows 64-bit only).
- know issues and notes
  * VirtualBox support on other platforms hasn’t been fully tested and
    bugs may still be present.
  * Regarding VirtualBox integration, we have plans to rewrite the
    back-end to add more features and remove the dependency on vboxwrapper.
  * We still have a couple of beta releases planned before
    our first release candidate.
* Wed Sep  3 2014 andrea@opensuse.org
- New upstream version 1.0 Beta 2
  * Improved VirtualBox support on Windows and Linux.
  * VirtualBox support on Linux/OSX requires VirtualBox wrapper version >= 9.1
  * New “enable console” option for VirtualBox VMs.
  * New “start at” option for VirtualBox VMs (adapter start index, 0 by default).
  * EtherSwitch support (based on a c3745 image).
  * Multi-drop feature (use SHIFT key while dropping a new node on the drawing area).
  * Default font and color for labels.
  * Support for rectangle and ellipse color transparency.
  * New topology summary options: filter devices with capture(s) and stop all captures.
  * Commands for the GNS3 console (version, start, stop, suspend, reload, show device, show run, help and debug).
  * Layers implementation (anything below layer 0 will be locked to the drawing area).
  * Numeric sorting for Ethernet/hub ports.
  * Restore default buttons for general, packet capture and GNS3 server preferences.
  * Changed the default port ranges.
  * Normalized capture file names.
  * More checks on device names, especially for IOS and IOU which forbid some characters.
  * Handles zoom in or out using the mouse wheel + CTRL. Resets the zoom using CTRL+0.
  * Prevent node labels to be deleted.
  * The sparse memory feature is off by default for c1700 and c2600 platforms (to prevent a bug on reboot).
* Thu Jul 24 2014 andrea@opensuse.org
- New upstream version 1.0 Beta 1
  * Base VirtualBox support (still some issues, most of them on Linux and Mac OS X).
  * Prevent users to set the port and VLAN settings to 0 on Ethernet swithes.
  * Fixed issue when spaces are in capture file paths.
  * Fixed bug with live capture on Windows.
  * Work around for the c7200 reload bug in Dynamips <= 0.2.13.
  * Fixed some inconsistencies when exporting configs.
  * The early release dialog is gone!
* Thu Jul 10 2014 andrea@opensuse.org
- New upstream version 1.0 alpha 8
  * New feature: insert an image on the view.
  * New feature: change node symbols.
  * Default port configuration for Ethernet switch and hub devices.
  * New feature: import/export device configs.
  * Fixed issue when deleting note items that had parent items.
  * Check the minimum required amount of RAM when adding IOS images.
  * Start a packet capture from the device contextual menu.
  * Improvements on the topology summary and link highlighting.
  * Find an alternative IOS or IOU image if one cannot be found when importing a topology.
  * Find an alternative Ethernet interface if one cannot be found when importing a topology.
  * Use Windows interface names instead of their GUID (more user friendly).
  * Fixed IOU and VPCS renaming issues.
  * Fixed size restoration issues for rectangles and ellipses when loading a project.
  * Check for VPCS version >= 0.5b1
  * Fixed errors when connecting an IOU device to a cloud.
  * Packet capture for IOU works with the latest iouyap version (0.95) available here.
* Tue Jul  1 2014 andrea@opensuse.org
- New upstream version 1.0 alpha 7
  * Packet capture for IOS routers.
  * Packet capture for the Ethernet hub and Ethernet,
    ATM and Frame relay switches.
  * Packet capture for IOU (not working, issue with iouyap).
  * Add notes, rectangles & ellipses to topologies.
  * Show/hide interface labels.
  * Contextual device menu.
  * Recent file menu.
  * Lab instructions support (automatically open any file named
    instructions.* in the project directory or from the Help menu)
  * Load a project by dropping the project file on the view.
  * Duplicate option for notes, rectangles and ellipses.
  * Style settings for note, rectangle and ellipse items. Possibility
    to edit interface and node labels.
  * Fix: use Dynamips, IOU and VPCS identifiers to correctly
    load topologies.
  * IOU: rename startup-config to initial-config (makes more
    sense for IOU).
  * Option to uncompress IOS images.
  * Check for sticky bit when checking for executable access.
  * Fix: IOS image relative path problems.
  * Lots of small bug fixes.
* Sat May 31 2014 andrea@opensuse.org
- New upstream version 1.0 alpha 6
  * New host names management.
  * New project dialog (in preparation for cloud support).
  * Logs saved to files (GNS3_client.log and GNS3_server.log).
  * Relative paths support for IOS/IOU images in project files.
  * Fixed decoding errors when reading device configs.
  * Fixed privileged access checks for IOU.
  * Fixed validation issue with c2600 XM chassis.
  * Fixed VPCS start on Linux/UNIX.
  * Fixed Ethernet hub when loading a project.
* Thu May 22 2014 andrea@opensuse.org
- New upstream version 1.0 alpha 5
  * VPCS support (only version >= 0.5b1
  * Fixed console port errors when loading a project.
  * Fixed startup-config errors when loading a project.
  * Fixed minor issues on Mac OS X (DMG file coming soon).
  * IOU default startup-configs for layer 2 and layer 3 images.
    Allowing for faster loading times too.
  * Option to prevent starting the local server when openning the GUI.
  * Prevent devices to be started, stopped or suspended if their status is not right
  * More checks for cloud connections.
  * Show item coordinates in the status bar.
  * Amend device configs (hostname) when renaming.
  * UDP connection checks.
* Thu May 15 2014 andrea@opensuse.org
- - New upstream version 1.0 alpha 4
  * Show Windows interface names in cloud tooltips.
  * Disconnect the server if the version differs from the GUI version.
  * Move cloud code to a builtin module and support for clouds on remote servers.
  * Options to use the default IOU RAM & NVRAM values.
  * Changed the name of default base startup and private configs.
  * Added “All files” filter when looking for an IOU or IOS image in the file broswer.
  * Graceful server shutdown on Windows.
  * Error message that JIT sharing is only supported in Dynamips unstable.
  * New UDP and console port allocation system for IOU. Fixes duplicated port issues.
  * Delete some Dynamips files that are useless to save in projects.
  * Fix: the path to GNS3 server was not saved.
  * Fix: RAM and NVRAM IOU image settings not propagated when creating an IOU device.
  * Fix: bug where IOS nvram/disk files were not kept after closing a topology.
  * Fix: bug that prevented changing any IOU device setting when connected to another node.
  * Fix: duplicated node id issue.
  * Fix: major bug with ghost instance overwriting any second router files (R2).
  * Fix: error when ldd cannot be found.
  * Fix: issues with local base configs for IOS.
* Sat May  3 2014 andrea@opensuse.org
- spec file inprovements hard coding minimum required version for dependencies
- new upstream version 1.0_alpha3
  * Follow the “VMware model” to organize projects.
  * Topology files have the .gns3 extension instead of .net (they are still supported).
  * Fixed problem to capture on TAP or Ethernet interfaces when not root.
  * Updated the upload page.
  * Server request validations.
  * Graceful shutdown for the server & modules
  * Checks for valid IOS & IOU images
  * Checks for missing shared library dependencies in an IOU image.
  * Explicit error message for missing 32-bit binary support on 64-bit Linux when starting IOU.
  * Check if iouyap can access Ethernet and TAP devices.
  * Windows network interfaces support in clouds (need improvements but it works…)
  * Update tooltips to show node IDs.
  * Ranges for Dynamips UDP, console, auxiliary console and hypervisor ports.
  * Use Dynamips UDP NIO auto back-end for UDP tunnel connections (excepting stubs).
  * The GUI can check the server version.
  * Explicitly show an error if an IOS network module cannot be added or removed.
  * Support for –version on the command line for both the server and GUI.
  * Delete IOS ghost files when closing a project.
  * Check for the correct locale on Linux/UNIX.
  * Fixed bugs with duplicated node IDs.
  * Save exception.log in the same directory as the GNS3 settings file.
  * Added the view -> docks menu.
  * Checks on node ID returned by the server.
* Fri Apr 18 2014 andrea@opensuse.org
- New upstream version 1.0_alpha2
  * IOS can now communicate with IOU devices running on a different host/VM.
  * Windows topology saving/loading issues have been fixed.
  * Improved non-blocking server connections.
  * Tooltips for all devices have been added.
  * Improved address/host binding implementation.
  * No need to first “save as” before saving an IOU topology.
  * Check for the required version of Dynamips (>= 0.2.11).
  * Checks for free console and aux ports.
  * Fixed local server shutdown on Windows.
  * Fixed bugs when changing local server settings.
  * Fixed c2600 router configuration errors.
  * File upload size limit to the server has been changed from 100MB (the default) to 500MB.
  * Fixed Frame-Relay & ATM issues when loading a topology.
  * Any computed idle-pc value is applied to all routers with the same IOS image.
  * New terminal command for ROXTerm.
  * Possibility to delete nodes using the delete key.
  * Fixed GUI inconsistencies and small bugs all over the place.
* Tue Apr  1 2014 andrea@opensuse.org
- new package using git service
